@@ -1,5 +1,5 @@
 package Text::Levenshtein;
-$Text::Levenshtein::VERSION = '0.12';
+$Text::Levenshtein::VERSION = '0.15';
 use 5.006;
 use strict;
 use warnings;
@@ -63,12 +63,13 @@ sub fastdistance
         $eq = $eq_with_diacritics;
     }
 
-    return 0 if $s eq $t;
-    return length($s) if !$t || length($t) == 0;
-    return length($t) if !$s || length($s) == 0;
+    my $s_length = defined($s) ? length($s) : 0;
+    my $t_length = defined($t) ? length($t) : 0;
 
-    my $s_length = length($s);
-    my $t_length = length($t);
+    return $s_length if $t_length == 0;
+    return $t_length if $s_length == 0;
+
+    return 0 if $s eq $t;
 
     for ($i = 0; $i < $t_length + 1; $i++) {
         $v0[$i] = $i;
@@ -183,6 +184,21 @@ L<Text::LevenshteinXS> and L<Text::Levenshtein::XS> are both versions
 of the Levenshtein algorithm that require a C compiler,
 but will be a lot faster than this module.
 
+L<Text::Levenshtein::Flexible> is another C implementation,
+but offers some twists: you can specify a maximum distance that
+you're interested in, which makes it faster;
+you can also give different costs to insertion, deletion,
+and substitution. Hasn't been updated since 2014.
+
+L<Text::Levenshtein::Edlib> is a Perl wrapper around a C++
+library that provides the Levenshtein edit distance and
+optimal alignment path for a pair of strings.
+It doesn't support UTF-8 strings, though.
+
+L<Text::Levenshtein::BV> implements the Levenshtein algorithm
+using bit vectors, and claims to be faster than this implementation.
+I haven't benchmarked them.
+
 The Damerau-Levenshtein edit distance is like the Levenshtein distance,
 but in addition to insertion, deletion and substitution, it also
 considers the transposition of two adjacent characters to be a single edit.
@@ -205,6 +221,14 @@ L<String::Similarity> takes two strings and returns a value between
 0 (meaning entirely different) and 1 (meaning identical).
 Apparently based on edit distance.
 
+L<Text::Dice> calculates
+L<Dice's coefficient|https://en.wikipedia.org/wiki/Sørensen–Dice_coefficient>
+for two strings. This formula was originally developed to measure the
+similarity of two different populations in ecological research.
+
+L<String::KeyboardDistance> and L<String::KeyboardDistanceXS>
+calculate the "keyboard distance" between two strings.
+
 =head1 REPOSITORY
 
 L<https://github.com/neilbowers/Text-Levenshtein>
